//
//  SavedHashtagsManager.swift
//  Tusker
//
//  Created by Shadowfacts on 12/19/19.
//  Copyright © 2019 Shadowfacts. All rights reserved.
//

import Foundation
import Pachyderm

class SavedHashtagsManager: Codable {
    private(set) static var shared: SavedHashtagsManager = load()
    
    private static var documentsDirectory = FileManager.default.urls(for: .documentDirectory, in: .userDomainMask).first!
    private static var archiveURL = SavedHashtagsManager.documentsDirectory.appendingPathComponent("saved_hashtags").appendingPathExtension("plist")
    
    static func save() {
        DispatchQueue.global(qos: .utility).async {
            let encoder = PropertyListEncoder()
            let data = try? encoder.encode(shared)
            try? data?.write(to: archiveURL, options: .noFileProtection)
        }
    }
    
    static func load() -> SavedHashtagsManager {
        let decoder = PropertyListDecoder()
        if let data = try? Data(contentsOf: archiveURL),
            let savedHashtagsManager = try? decoder.decode(Self.self, from: data) {
            return savedHashtagsManager
        }
        return SavedHashtagsManager()
    }
    
    private init() {}
    
    private var savedHashtags: [Hashtag] = []
    var sorted: [Hashtag] {
        return savedHashtags.sorted(by: { $0.name < $1.name })
    }
    
    func isSaved(_ hashtag: Hashtag) -> Bool {
        return savedHashtags.contains(hashtag)
    }
    
    func add(_ hashtag: Hashtag) {
        if isSaved(hashtag) {
            return
        }
        savedHashtags.append(hashtag)
        SavedHashtagsManager.save()
        NotificationCenter.default.post(name: .savedHashtagsChanged, object: nil)
    }
    
    func remove(_ hashtag: Hashtag) {
        guard isSaved(hashtag) else { return }
        savedHashtags.removeAll(where: { $0.name == hashtag.name })
        SavedHashtagsManager.save()
        NotificationCenter.default.post(name: .savedHashtagsChanged, object: nil)
    }
}

extension Foundation.Notification.Name {
    static let savedHashtagsChanged = Notification.Name("savedHashtagsChanged")
}
